Rename art-cache to dalvik-cache

Change-Id: I294995066aecc29fbd739c3e9e6f60934f743064
diff --git a/src/class_linker.cc b/src/class_linker.cc
index cfad9d1..85bd9f6 100644
--- a/src/class_linker.cc
+++ b/src/class_linker.cc
@@ -884,9 +884,9 @@
       return dex_file;
     }
   }
-  // Look for an existing file in the art-cache, validating the result if found
-  // not found in /foo/bar/baz.oat? try /data/art-cache/foo@bar@baz.oat
-  std::string cache_location(GetArtCacheFilenameOrDie(oat_filename));
+  // Look for an existing file in the dalvik-cache, validating the result if found
+  // not found in /foo/bar/baz.oat? try /data/dalvik-cache/foo@bar@baz.oat
+  std::string cache_location(GetDalvikCacheFilenameOrDie(oat_filename));
   oat_file = FindOatFileFromOatLocationLocked(cache_location);
   if (oat_file != NULL) {
     uint32_t dex_location_checksum;
@@ -907,7 +907,7 @@
   LOG(INFO) << "Failed to open oat file from " << oat_filename << " or " << cache_location << ".";
 
   // Try to generate oat file if it wasn't found or was obsolete.
-  std::string oat_cache_filename(GetArtCacheFilenameOrDie(oat_filename));
+  std::string oat_cache_filename(GetDalvikCacheFilenameOrDie(oat_filename));
   return FindOrCreateOatFileForDexLocationLocked(dex_location, oat_cache_filename);
 }